@@ -43,7 +43,7 @@ def main() -> None:
             host=argument_dict["host"], port=argument_dict["zmqport"]
         )
 
-    memory = None
+    memory = {"executorlib_worker_id": int(argument_dict["worker_id"])}
 
     # required for flux interface - otherwise the current path is not included in the python path
     cwd = abspath(".")
@@ -97,7 +97,7 @@ def main() -> None:
             and "args" in input_dict
             and "kwargs" in input_dict
         ):
-            memory = call_funct(input_dict=input_dict, funct=None)
+            memory.update(call_funct(input_dict=input_dict, funct=None, memory=memory))
 
 
 if __name__ == "__main__":
